"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@ts-ioc/core");
const IApplicationBuilder_1 = require("./IApplicationBuilder");
const RunnableBuilder_1 = require("./RunnableBuilder");
/**
 * application events
 *
 * @export
 * @enum {number}
 */
exports.AppEvents = RunnableBuilder_1.RunnableEvents;
/**
 * application events
 */
exports.ApplicationEvents = RunnableBuilder_1.RunnableEvents;
/**
 * application builder.
 *
 * @export
 * @class Default ApplicationBuilder
 * @extends {ModuleBuilder}
 * @template T
 */
let ApplicationBuilder = class ApplicationBuilder extends RunnableBuilder_1.RunnableBuilder {
    constructor(baseURL) {
        super(baseURL);
        this.configs = [];
    }
    /**
     * use configuration.
     *
     * @param {(string | AppConfigure)} [config]
     * @returns {this} global config for this application.
     * @memberof Bootstrap
     */
    useConfiguration(config) {
        if (this.configMgr) {
            this.configMgr.useConfiguration(config);
        }
        this.configs.push(config);
        return this;
    }
    createConfigureMgr() {
        let cfgMgr = super.createConfigureMgr();
        if (this.configs && this.configs.length) {
            this.configs.forEach(cfg => cfgMgr.useConfiguration(cfg));
        }
        return cfgMgr;
    }
};
ApplicationBuilder.classAnnations = { "name": "ApplicationBuilder", "params": { "constructor": ["baseURL"], "useConfiguration": ["config"], "createConfigureMgr": [] } };
ApplicationBuilder = tslib_1.__decorate([
    core_1.Injectable(IApplicationBuilder_1.ApplicationBuilderToken),
    tslib_1.__metadata("design:paramtypes", [String])
], ApplicationBuilder);
exports.ApplicationBuilder = ApplicationBuilder;

//# sourceMappingURL=../sourcemaps/boot/ApplicationBuilder.js.map
