import { IContainer } from '@ts-ioc/core';
import { IConfigureManager } from './IConfigureManager';
import { RunnableConfigure } from './AppConfigure';
/**
 * configure manager.
 *
 * @export
 * @class ConfigureManager
 */
export declare class ConfigureManager<T extends RunnableConfigure> implements IConfigureManager<T> {
    protected baseURL?: string;
    /**
     * Creates an instance of ConfigureManager.
     * @param {string} [baseURL]
     * @memberof ConfigureManager
     */
    constructor(baseURL?: string);
    container: IContainer;
    private config;
    protected configs: (string | T)[];
    /**
     * use configuration.
     *
     * @param {(string | AppConfigure)} [config]
     * @returns {this} this configure manager.
     * @memberof Bootstrap
     */
    useConfiguration(config?: string | T): this;
    /**
     * get config.
     *
     * @returns {Promise<T>}
     * @memberof ConfigureManager
     */
    getConfig(): Promise<T>;
    /**
     * init config.
     *
     * @protected
     * @returns
     * @memberof ConfigureManager
     */
    protected initConfig(): Promise<T>;
    /**
     * load config.
     *
     * @protected
     * @param {string} src
     * @returns {Promise<T>}
     * @memberof ConfigureManager
     */
    protected loadConfig(src: string): Promise<T>;
    /**
     * get default config.
     *
     * @protected
     * @returns {Promise<T>}
     * @memberof ConfigureManager
     */
    protected getDefaultConfig(): Promise<T>;
    static classAnnations: any;
}
