"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@ts-ioc/core");
/**
 * injected module.
 *
 * @export
 * @class InjectedModule
 * @template T
 */
class InjectedModule {
    constructor(token, config, container, type, exports) {
        this.token = token;
        this.config = config;
        this.container = container;
        this.type = type;
        this.exports = exports;
    }
    getProviderMap() {
        if (!this._map) {
            this._map = this.container.resolveValue(new core_1.InjectReference(core_1.ProviderMap, this.type || this.token));
        }
        return this._map;
    }
    resolve(token, ...providers) {
        let pdr = this.getProviderMap();
        if (pdr && pdr.hasRegister(token)) {
            return pdr.resolve(token, ...providers);
        }
        else {
            return this.container.resolveValue(token, ...providers);
        }
    }
    hasRegister(key) {
        let pdr = this.getProviderMap();
        if (pdr && pdr.hasRegister(key)) {
            return true;
        }
        else {
            return this.container.hasRegister(key);
        }
    }
    forEach(callbackfn) {
        let pdr = this.getProviderMap();
        if (pdr) {
            pdr.forEach((fac, tk) => {
                core_1.isToken(tk) && callbackfn(tk, fac, pdr);
            });
        }
        this.container.forEach((tk, fac) => {
            callbackfn(tk, fac, this.container);
        });
    }
}
InjectedModule.classAnnations = { "name": "InjectedModule", "params": { "constructor": ["token", "config", "container", "type", "exports"], "getProviderMap": [], "resolve": ["token", "providers"], "hasRegister": ["key"], "forEach": ["callbackfn"] } };
exports.InjectedModule = InjectedModule;
/**
 * Injected Module Token.
 *
 * @export
 * @class InjectModuleMetaConfigToken
 * @extends {Registration<Type<T>>}
 * @template T
 */
class InjectedModuleToken extends core_1.Registration {
    constructor(type) {
        super(type, 'InjectedModule');
    }
}
InjectedModuleToken.classAnnations = { "name": "InjectedModuleToken", "params": { "constructor": ["type"] } };
exports.InjectedModuleToken = InjectedModuleToken;

//# sourceMappingURL=../sourcemaps/modules/InjectedModule.js.map
