import { Token, IContainer } from '@ts-ioc/core';
import { ModuleConfigure, BootOptions } from '../modules';
/**
 * boot.
 *
 * @export
 * @interface IBoot
 * @template T
 */
export interface IRunnable<T> {
    /**
     * container.
     *
     * @type {IContainer}
     * @memberof IBoot
     */
    container: IContainer;
    /**
     * target instance.
     *
     * @type {T}
     * @memberof IBoot
     */
    getTarget(): T;
    /**
     * get target token.
     *
     * @returns {Token<T>}
     * @memberof IBoot
     */
    getTargetToken(): Token<T>;
    /**
     * on boot init.
     *
     * @param {BootOptions<T>} options
     * @returns {Promise<void>}
     * @memberof IBoot
     */
    onInit?(options: BootOptions<T>): Promise<void>;
}
/**
 * boot.
 *
 * @export
 * @class Boot
 * @implements {IBoot<T>}
 * @template T
 */
export declare class RunnableBase<T> implements IRunnable<T> {
    protected token?: Token<T>;
    protected instance?: T;
    protected config?: ModuleConfigure;
    container: IContainer;
    constructor(token?: Token<T>, instance?: T, config?: ModuleConfigure);
    getTarget(): T;
    getTargetToken(): Token<T>;
    static classAnnations: any;
}
/**
 * target is Runnable or not.
 *
 * @export
 * @param {*} target
 * @returns {target is RunnableBase<any>}
 */
export declare function isRunnable(target: any): target is RunnableBase<any>;
