import { Token } from '@ts-ioc/core';
import { ModuleConfigure } from '../modules';
import { IRunnable, RunnableBase } from './Runnable';
/**
 * application runer.
 *
 * @export
 * @interface IRunner
 * @template T
 */
export interface IRunner<T> extends IRunnable<T> {
    /**
     * run application via boot instance.
     *
     * @param {*} [data]
     * @returns {Promise<any>}
     * @memberof IRunner
     */
    run(data?: any): Promise<any>;
}
/**
 * boot element.
 *
 * @export
 * @abstract
 * @class Boot
 * @implements {IBoot}
 */
export declare abstract class Runner<T> extends RunnableBase<T> implements IRunner<T> {
    constructor(token?: Token<T>, instance?: T, config?: ModuleConfigure);
    /**
     * run boot.
     *
     * @abstract
     * @param {*} [data]
     * @returns {Promise<any>}
     * @memberof Runner
     */
    abstract run(data?: any): Promise<any>;
    static classAnnations: any;
}
/**
 * target is runner or not.
 *
 * @export
 * @param {*} target
 * @returns {target is IRunner<any>}
 */
export declare function isRunner(target: any): target is IRunner<any>;
