import { Token } from '@ts-ioc/core';
import { ModuleConfigure } from '../modules';
import { IRunnable, RunnableBase } from './Runnable';
/**
 * IService interface
 *
 * @export
 * @interface IService
 */
export interface IService<T> extends IRunnable<T> {
    /**
     * start application service.
     *
     * @returns {Promise<any>}
     * @memberof IService
     */
    start(data?: any): Promise<any>;
    /**
     * stop server.
     *
     * @returns {Promise<any>}
     * @memberof IService
     */
    stop?(): Promise<any>;
}
/**
 * base service.
 *
 * @export
 * @abstract
 * @class Service
 * @implements {IService}
 */
export declare abstract class Service<T> extends RunnableBase<T> implements IService<T> {
    constructor(token?: Token<T>, instance?: T, config?: ModuleConfigure);
    /**
     * start service.
     *
     * @abstract
     * @param {*} [data]
     * @returns {Promise<any>}
     * @memberof Service
     */
    abstract start(data?: any): Promise<any>;
    /**
     * stop service.
     *
     * @abstract
     * @returns {Promise<any>}
     * @memberof Service
     */
    abstract stop(): Promise<any>;
    static classAnnations: any;
}
/**
 * target is service or not.
 *
 * @export
 * @param {*} target
 * @returns {target is IService<any>}
 */
export declare function isService(target: any): target is IService<any>;
