"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@ts-ioc/core");
const rootContainer = '__ioc_root_container';
/**
 * container pool
 *
 * @export
 * @class ContainerPool
 */
class ContainerPool {
    constructor(containerBuilder) {
        this.containerBuilder = containerBuilder;
        this.pools = new Map();
    }
    createContainer() {
        return this.containerBuilder.create();
    }
    getTokenKey(token) {
        if (token instanceof core_1.Registration) {
            return token.toString();
        }
        return token;
    }
    isDefault(container) {
        return container === this._default;
    }
    hasDefault() {
        return !!this._default;
    }
    getDefault() {
        if (!this._default) {
            this._default = this.createContainer();
            this.pools.set(rootContainer, this._default);
        }
        return this._default;
    }
    set(token, container) {
        let key = this.getTokenKey(token);
        if (this.pools.has(key)) {
            console.log(`${token.toString()} module has loaded`);
        }
        this.pools.set(key, container);
    }
    get(token) {
        let key = this.getTokenKey(token);
        if (!this.has(key)) {
            return null;
        }
        return this.pools.get(token);
    }
    has(token) {
        return this.pools.has(this.getTokenKey(token));
    }
    create(token, parent) {
        parent = parent || this.getDefault();
        let container = parent.getBuilder().create();
        this.setParent(container, parent);
        this.set(token, container);
        return container;
    }
    setParent(container, parent) {
        if (this.isDefault(container)) {
            return;
        }
        parent = parent || this.getDefault();
        if (parent && parent !== container) {
            if (container.parent) {
                container.parent.children.splice(container.parent.children.indexOf(container), 1);
            }
            parent.children.push(container);
            container.parent = parent;
        }
    }
    keys() {
        return Array.from(this.pools.keys());
    }
    values() {
        return Array.from(this.pools.values());
    }
    forEach(callbackfn, thisArg) {
        this.pools.forEach(callbackfn, thisArg);
    }
    iterator(express, root) {
        root = root || this.getDefault();
        express(root);
        this.iteratorChildren(express, root.children);
    }
    iteratorChildren(express, children) {
        if (children && children.length) {
            children.forEach(c => {
                express(c);
                this.iteratorChildren(express, c.children);
            });
        }
    }
}
ContainerPool.classAnnations = { "name": "ContainerPool", "params": { "constructor": ["containerBuilder"], "createContainer": [], "getTokenKey": ["token"], "isDefault": ["container"], "hasDefault": [], "getDefault": [], "set": ["token", "container"], "get": ["token"], "has": ["token"], "create": ["token", "parent"], "setParent": ["container", "parent"], "keys": [], "values": [], "forEach": ["callbackfn", "thisArg"], "iterator": ["express", "root"], "iteratorChildren": ["express", "children"] } };
exports.ContainerPool = ContainerPool;
/**
 *  container pool token.
 */
exports.ContainerPoolToken = new core_1.InjectToken('DI_ContainerPool');

//# sourceMappingURL=../sourcemaps/utils/ContainerPool.js.map
