"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@ts-ioc/core");
/**
 * custom events.
 *
 * @export
 * @class Events
 */
class Events {
    constructor() {
        this.eventsMap = {};
    }
    on(name, event) {
        this.eventsMap[name] = this.eventsMap[name] || [];
        if (this.eventsMap[name].indexOf(event) < 0) {
            this.eventsMap[name].push(event);
        }
        return this;
    }
    once(name, event) {
        let onceEvent = (...args) => {
            event(...args);
            this.off(name, onceEvent);
        };
        this.on(name, onceEvent);
    }
    off(name, event) {
        if (this.eventsMap[name]) {
            if (event) {
                this.eventsMap[name].splice(this.eventsMap[name].indexOf(event), 1);
            }
            else {
                delete this.eventsMap[name];
            }
        }
        return this;
    }
    emit(name, ...args) {
        let events = this.eventsMap[name];
        if (core_1.isArray(events)) {
            events.forEach(ev => {
                ev(...args);
            });
        }
    }
}
Events.classAnnations = { "name": "Events", "params": { "constructor": [], "on": ["name", "event"], "once": ["name", "event"], "off": ["name", "event"], "emit": ["name", "args"] } };
exports.Events = Events;

//# sourceMappingURL=../sourcemaps/utils/Events.js.map
